@@ -3,4 +3,4 @@ from ..operations import FilterLine
 
 class RemoveMacros(FilterLine):
     def filter_line(self, line: str) -> bool:
-        return not line.startswith('#jp-')
+        return not line.startswith(('#jp-', '--jp-'))
