@@ -1,9 +1,10 @@
 from .EmbedImages import EmbedImages
 from .RemoveCellByMacro import RemoveCellByMacro
 from .RemoveEmptyCell import RemoveEmptyCell
-from .RemoveTrailingLines import RemoveTrailingLines
-from .RemoveMacros import RemoveMacros
+from .RemoveMacrosFromCode import RemoveMacrosFromCode
+from .RemoveMacrosFromTags import RemoveMacrosFromTags
 from .RemovePyCharm import RemovePyCharm
+from .RemoveTrailingLines import RemoveTrailingLines
 from .SetReadonly import SetReadonly
 from .SetUndeletable import SetUndeletable
 from .StripLines import StripLines
